@@ -1,4 +1,5 @@
 from dataclasses import dataclass, field
+from typing import List
 
 from dataclasses_json import config, dataclass_json
 
@@ -16,7 +17,7 @@ class Description(object):
 class Commit(ActivityObject):
     # https://forgefed.peers.community/modeling.html#commit
     type: str = "Commit"
-    jsonld_context: list = field(metadata=config(field_name="@context"), default=None)
+    jsonld_context: List[str] = field(metadata=config(field_name="@context"), default=None)
     context: str = None
     attributedTo: str = None
     created: str = None
