@@ -12,7 +12,7 @@ class Git(DVCS):
     def __init__(self, dir, url):
         self._url = url
         self.d = dir
-        self.g = sh.git.bake("-C", self.d)
+        self.g = sh.git.bake("-C", self.d, _tty_out=False)
 
     @property
     def directory(self):
@@ -29,6 +29,9 @@ class Git(DVCS):
     def hash(self):
         return git.Repo(self.d).head.commit.hexsha
 
+    def log(self):
+        return [e.strip() for e in self.g.log("--pretty=tformat:%H", _iter=True)]
+
     def fetch(self, url, hash):
         if self._commit_exists(hash):
             return False
@@ -92,6 +95,6 @@ class Git(DVCS):
         self.g.checkout(branch)
         self.g.push("--force", "origin", branch)
 
-    def commit(self, message, *pathnames):
-        self.g.add(*pathnames)
+    def commit(self, message):
+        self.g.add("--all")
         self.g.commit("-m", message)
