@@ -37,7 +37,7 @@ def test_dvcs_commit(dvcs, tmpdir):
     assert dvcs.clone("master") is True
     content = "C"
     open(f"{dvcs.directory}/README.md", "w").write(content)
-    dvcs.commit("message", "README.md")
+    dvcs.commit("message")
     dvcs.push("master")
 
     DVCS = type(dvcs)
@@ -46,6 +46,19 @@ def test_dvcs_commit(dvcs, tmpdir):
     assert open(f"{other_dvcs.directory}/README.md").read() == content
 
 
+def test_dvcs_log(dvcs, tmpdir):
+    assert dvcs.clone("master") is True
+    hash1 = dvcs.hash
+    content = "C"
+    open(f"{dvcs.directory}/README.md", "w").write(content)
+    dvcs.commit("message")
+    dvcs.push("master")
+    hash0 = dvcs.hash
+    log = dvcs.log()
+    assert log[0] == hash0
+    assert log[1] == hash1
+
+
 def test_dvcs_push_pull(dvcs, tmpdir):
     assert dvcs.clone("master") is True
 
@@ -54,7 +67,7 @@ def test_dvcs_push_pull(dvcs, tmpdir):
     assert other_dvcs.clone("master") is True
     content = "C"
     open(f"{other_dvcs.directory}/README.md", "w").write(content)
-    other_dvcs.commit("message", "README.md")
+    other_dvcs.commit("message")
     other_dvcs.push("master")
 
     dvcs.pull("master")
