@@ -1,4 +1,3 @@
-import os
 import time
 
 import pytest
@@ -6,54 +5,50 @@ import sh
 
 from .architecture.dvcs.git import Git
 from .architecture.dvcs.hg import Hg
-from .architecture.forge.gitea import Gitea
-from .architecture.forge.gitlab import GitLab
+from .architecture.forge.test_gitea import params as params_gitea
+from .architecture.forge.test_gitlab import params as params_gitlab
 from .domain.fedeproxy import Fedeproxy
 
 forge_params = [
-    (Gitea, f"http://{os.environ.get('MY_IP', '0.0.0.0')}:8781"),
-    (GitLab, f"http://{os.environ.get('MY_IP', '0.0.0.0')}:8181"),
+    params_gitea,
+    params_gitlab,
 ]
-forge_ids = [p[0].__name__ for p in forge_params]
+forge_ids = [p["name"] for p in forge_params]
 
 
 def skip_excluded_forges(request):
     marker = request.node.get_closest_marker("forges")
-    (Forge, url) = request.param
     if marker is not None:
         forges = marker.args[0]
-        if Forge.__name__ not in forges:
-            pytest.skip(f"the test has a 'mark' excluding {Forge.__name__} ")
+        if request.param["name"] not in forges:
+            pytest.skip(f"the test has a 'mark' excluding {request.param['name']} ")
 
 
-@pytest.fixture(params=forge_params, ids=forge_ids)
-def fedeproxy(request, tmpdir, make_user, testuser, password, testproject, make_project):
-    skip_excluded_forges(request)
-    (Forge, url) = request.param
+@pytest.fixture
+def fedeproxy(forge_factory, tmpdir, make_identity, testuser, password, testproject, make_project):
+    (Forge, url) = (forge_factory["class"], forge_factory["url"])
     f = Fedeproxy(Forge, url, f"{tmpdir}/fedeproxy")
 
-    make_user(f.own, f.own.owner)
-    f.own.authenticate(username=f.own.owner, password=password)
-    make_project(f.own, f.own.namespace, "fedeproxy")
+    make_identity(f, f.owner)
+    f.load()
+    make_project(f.own, f.namespace, "fedeproxy")
 
-    f.init()
-
-    make_user(f.forge, testuser)
+    make_identity(f, testuser)
     f.forge.authenticate(username=testuser, password=password)
     make_project(f.forge, testuser, testproject)
 
     return f
 
 
-@pytest.fixture(params=forge_params, ids=forge_ids)
-def forge(request):
-    skip_excluded_forges(request)
-    (Forge, url) = request.param
+@pytest.fixture
+def forge(forge_factory):
+    (Forge, url) = (forge_factory["class"], forge_factory["url"])
     return Forge(url)
 
 
 @pytest.fixture(params=forge_params, ids=forge_ids)
 def forge_factory(request):
+    skip_excluded_forges(request)
     return request.param
 
 
@@ -79,7 +74,12 @@ def make_user(password):
 
     def _make_user(forge, username):
         forge.authenticate(username="root", password="Wrobyak4")
-        forge.users.delete(username)
+        user = forge.users.get(username)
+        if user:
+            for project in user.projects:
+                forge.projects.delete(username, project.project)
+
+            forge.users.delete(username)
         email = f"{username}@example.com"
         user = forge.users.create(username, password, email)
         contexts.append((forge, username))
@@ -88,18 +88,32 @@ def make_user(password):
     yield _make_user
 
     for (forge, username) in contexts:
-        forge.authenticate(username="root", password="Wrobyak4")
+        if not forge.is_authenticated or not forge.is_admin:
+            forge.authenticate(username="root", password="Wrobyak4")
+        user = forge.users.get(username)
+        if user:
+            for project in user.projects:
+                forge.projects.delete(username, project.project)
         forge.users.delete(username)
 
 
+@pytest.fixture
+def make_identity(make_user, password):
+    def _make_identity(fedeproxy, username):
+        user = make_user(fedeproxy.own, username)
+        return fedeproxy.identity_create(user, password)
+
+    yield _make_identity
+
+
 @pytest.fixture
 def make_project(password):
 
     contexts = []
 
-    def _make_project(forge, username, project):
-        forge.project_delete(username, project)
-        p = forge.project_create(username, project)
+    def _make_project(forge, username, project, **data):
+        forge.projects.delete(username, project)
+        p = forge.projects.create(username, project, **data)
         contexts.append((forge, username, project))
         return p
 
@@ -107,7 +121,7 @@ def make_project(password):
 
     for (forge, username, project) in contexts:
         forge.authenticate(username="root", password=password)
-        forge.project_delete(username, project)
+        forge.projects.delete(username, project)
 
 
 class Repository(object):
