@@ -12,7 +12,14 @@ class Fedeproxy:
             settings.FEDEPROXY_FORGE_DIRECTORY,
         )
 
+    def authenticate(self):
+        if self.fedeproxy.own.is_authenticated:
+            return False
+        self.fedeproxy.load()
+        return True
+
     def __call__(self, request):
+        self.authenticate()
         request.fedeproxy = self.fedeproxy
         response = self.get_response(request)
         return response
