@@ -48,18 +48,15 @@ class IdentityPublic(Identity):
 
 
 class Identities(object):
-    def __init__(self, own):
-        self.own = own
+    def __init__(self, d):
+        self.d = d
+        if not os.path.exists(self.d):
+            os.makedirs(self.d)
+        self.p = f"{self.d}/identities.json"
         self.email = None
         self.identities = []
 
-    def init(self):
-        self.d = self.own.own_project_create().dvcs()
-        self.p = f"{self.d.directory}/identities.json"
-        self.load()
-
     def load(self):
-        self.d.clone("identities")
         if os.path.exists(self.p):
             f = format.FormatIdentities()
             identities = f.load(self.p)
@@ -73,6 +70,12 @@ class Identities(object):
     def save(self):
         format.FormatIdentities().save(self.p, [i.asdict() for i in self.identities])
 
+    def lookup(self, cmp):
+        for i in self.identities:
+            if cmp(i):
+                return i
+        return None
+
 
 class IdentitiesPrivate(Identities):
 
