@@ -57,17 +57,15 @@ def test_identity_public(identity_sample):
     assert identity.IdentityPublic(**expected).asdict() == expected
 
 
-def test_identities(fedeproxy, identity_sample):
-    identities = identity.IdentitiesPrivate(fedeproxy.own)
-    identities.init()
+def test_identities(tmpdir, identity_sample):
+    identities = identity.IdentitiesPrivate(tmpdir)
     assert identities.load() is False
     assert identities.identities == []
     i = identity.IdentityPrivate(**identity_sample)
     identities.identities.append(i)
     identities.save()
 
-    identities = identity.IdentitiesPrivate(fedeproxy.own)
-    identities.init()
+    identities = identity.IdentitiesPrivate(tmpdir)
     assert identities.load() is True
     identity_loaded = identities.identities[0]
     assert identity_loaded.asdict() == identity_sample
