@@ -25,6 +25,10 @@ class DVCS(abc.ABC):
     def hash(self):
         ...
 
+    @abc.abstractmethod
+    def log(self):
+        ...
+
     @abc.abstractmethod
     def fetch(self, url, hash):
         ...
@@ -46,5 +50,5 @@ class DVCS(abc.ABC):
         ...
 
     @abc.abstractmethod
-    def commit(self, message, *pathnames):
+    def commit(self, message):
         ...
