@@ -43,6 +43,7 @@ class Forge(Persistent):
     def __init__(self, url):
         self._url = url
         self._users = self.users_factory()(self)
+        self._projects = self.projects_factory()(self)
 
     @property
     def url(self):
@@ -52,11 +53,20 @@ class Forge(Persistent):
     def s(self):
         return self._s
 
+    @property
+    def is_authenticated(self):
+        ...
+
     @property
     @abc.abstractmethod
     def username(self):
         ...
 
+    @property
+    @abc.abstractmethod
+    def is_admin(self):
+        ...
+
     @abc.abstractmethod
     def authenticate(self, **kwargs):
         ...
@@ -69,6 +79,10 @@ class Forge(Persistent):
     def is_dvcs_supported(self, DVCS):
         ...
 
+    @abc.abstractmethod
+    def hook_factory(self, payload):
+        ...
+
     @abc.abstractmethod
     def users_factory(self):
         ...
@@ -77,20 +91,61 @@ class Forge(Persistent):
     def users(self):
         return self._users
 
+    @abc.abstractmethod
+    def projects_factory(self):
+        ...
+
+    @property
+    def projects(self):
+        return self._projects
+
+    @abc.abstractmethod
+    def hook_register(self, url):
+        ...
+
+
+class Hook(abc.ABC):
+    def __init__(self, payload):
+        self._payload = payload
+
+    @property
+    def payload(self):
+        return self._payload
+
+
+class HookCommit(Hook):
+    @property
+    @abc.abstractmethod
+    def hash(self):
+        ...
+
+
+class Projects(Collection):
+    def __init__(self, forge):
+        self._forge = forge
+
+    @property
+    def forge(self):
+        return self._forge
+
+    @property
+    def s(self):
+        return self.forge.s
+
     @abc.abstractmethod
     def project_factory(self):
         ...
 
     @abc.abstractmethod
-    def project_get(self, namespace, project):
+    def get(self, namespace, project):
         ...
 
     @abc.abstractmethod
-    def project_create(self, namespace, project, **data):
+    def create(self, namespace, project, **data):
         ...
 
     @abc.abstractmethod
-    def project_delete(self, namespace, project):
+    def delete(self, namespace, project):
         ...
 
 
@@ -158,6 +213,20 @@ class Project(Persistent):
     def dvcs(self, directory):
         ...
 
+    @abc.abstractmethod
+    def hook_register(self, url):
+        ...
+
+    def __eq__(self, other):
+        return (
+            isinstance(other, Project)
+            and self.id == other.id
+            and self.namespace == other.namespace
+            and self.project == other.project
+            and self.http_url_to_repo == other.http_url_to_repo
+            and self.ssh_url_to_repo == other.ssh_url_to_repo
+        )
+
 
 class Milestones(Persistent, Collection):
     def __init__(self, project):
@@ -190,6 +259,19 @@ class Milestone(abc.ABC):
     def id(self):
         ...
 
+    @property
+    @abc.abstractmethod
+    def title(self):
+        ...
+
+    def __eq__(self, other):
+        return (
+            isinstance(other, Milestone)
+            and self.project == other.project
+            and self.id == other.id
+            and self.title == other.title
+        )
+
 
 class Issues(Persistent, Collection):
     def __init__(self, project):
@@ -235,6 +317,10 @@ class Users(Persistent, Collection):
     def s(self):
         return self.forge.s
 
+    @abc.abstractmethod
+    def convert_url_to_username(self, url):
+        ...
+
 
 class User(Jsonable):
     def __init__(self, forge, user):
@@ -263,3 +349,16 @@ class User(Jsonable):
     @abc.abstractmethod
     def emails(self):
         ...
+
+    @property
+    @abc.abstractmethod
+    def projects(self):
+        ...
+
+    def __eq__(self, other):
+        return (
+            isinstance(other, User)
+            and self.forge == other.forge
+            and self.url == other.url
+            and self.username == other.username
+        )
