@@ -3,7 +3,8 @@ from rest_framework.test import APIClient
 
 
 def test_nodeinfo(tmpdir, settings, forge_factory):
-    (settings.FEDEPROXY_FORGE_FACTORY, settings.FEDEPROXY_FORGE_URL) = forge_factory
+    settings.FEDEPROXY_FORGE_FACTORY = forge_factory["class"]
+    settings.FEDEPROXY_FORGE_URL = forge_factory["url"]
     settings.FEDEPROXY_FORGE_DIRECTORY = str(tmpdir)
 
     client = APIClient()
