@@ -37,17 +37,21 @@ function setup_gitlab() {
 }
 
 function setup() {
-    setup_gitlab 1
-    setup_gitlab 2
+    local serial
+    for serial in $serials ; do
+	setup_gitlab $serial
+    done
 }
 
 function teardown() {
     local serial
-    for serial in 1 2 ; do
+    for serial in $serials ; do
 	cleanup $serial
     done
 }
 
+: ${serials:=1 2}
+
 for f in prepare_environment ${@:-teardown setup} ; do
     $f
 done
